@@ -12,11 +12,19 @@ from common_util import *
 def random_proxy_header_access(url: str, proxy: str = '',
                                require_proxy: bool = False, max_retry: int = 10, sleep_time: float = 1.2,
                                random_proxy: bool = True, time_out: tuple = (10, 20),
-                               need_log: bool = True, cookie: str = "", if_bytes_encoding: str = "utf-8") -> str:
+                               need_log: bool = True, cookie: str = "", if_bytes_encoding: str = "utf-8",
+                               method: str = GET, get_params: List[tuple] or dict or bytes = None,
+                               post_data: dict or List[tuple] or bytes = None,
+                               json=None, allow_redirects: bool = True) -> str:
     """
     如果达到max_retry之后，仍然访问不到，返回空值
     use random header and proxy to access url and get content
     if access the url beyond max_retry, will return a blank string
+    :param allow_redirects: 是否启用重定向
+    :param json: 请求体json序列化对象
+    :param method: 请求方法
+    :param post_data: POST方式的请求体数据
+    :param get_params: URL参数
     :param if_bytes_encoding: 如果爬取到的是字节，需要通过什么字符集转换
     :param cookie: 对于需要cookie即登录才能访问的网站，需要提供cookie
     :param need_log: 是否需要日志
@@ -27,8 +35,8 @@ def random_proxy_header_access(url: str, proxy: str = '',
     :param sleep_time:每次爬取睡眠时间
     :return:返回爬取的网页或者最大尝试次数之后返回空
     :param random_proxy:随机使用代理，默认为真，随机使用真实地址而不使用代理
-    :param time_out: 一个元组或者整数，元组前者表示连接超时阈值，后者表示获取内容超时阈值、
-                    如果是整数，则两者值设为一样
+    :param time_out: 一个元组或者浮点数，元组前者表示连接超时阈值，后者表示获取内容超时阈值、
+                    如果是浮点数，则两者值设为一样
     """
     proxy_provide = False
     cookie_jar = RequestsCookieJar()
@@ -57,17 +65,27 @@ def random_proxy_header_access(url: str, proxy: str = '',
                 if random_proxy and two_one_choose():
                     if need_log:
                         log("随机使用代理")
-                    request = requests.get(url, headers=headers, proxies=proxies, timeout=time_out, cookies=cookie_jar)
+                    request = requests.request(method=method, url=url, headers=headers, proxies=proxies,
+                                               timeout=time_out, cookies=cookie_jar, allow_redirects=allow_redirects,
+                                               json=json, data=post_data, params=get_params)
                 elif random_proxy and not two_one_choose():
                     if need_log:
                         log("随机不使用代理")
-                    request = requests.get(url, headers=headers, timeout=time_out, cookies=cookie_jar)
+                    request = requests.request(method=method, url=url, headers=headers, timeout=time_out,
+                                               cookies=cookie_jar, allow_redirects=allow_redirects,
+                                               json=json, data=post_data, params=get_params)
                 elif not random_proxy:
-                    request = requests.get(url, headers=headers, proxies=proxies, timeout=time_out, cookies=cookie_jar)
+                    request = requests.request(method=method, url=url, headers=headers, proxies=proxies,
+                                               timeout=time_out, cookies=cookie_jar, allow_redirects=allow_redirects,
+                                               json=json, data=post_data, params=get_params)
                 else:
-                    request = requests.get(url, headers=headers, proxies=proxies, timeout=time_out, cookies=cookie_jar)
+                    request = requests.request(method=method, url=url, headers=headers, proxies=proxies,
+                                               timeout=time_out, cookies=cookie_jar, allow_redirects=allow_redirects,
+                                               json=json, data=post_data, params=get_params)
             else:
-                request = requests.get(url, headers=headers, timeout=time_out, cookies=cookie_jar)
+                request = requests.request(method=method, url=url, headers=headers, timeout=time_out, cookies=cookie_jar
+                                           , allow_redirects=allow_redirects, json=json, data=post_data,
+                                           params=get_params)
             html = request.content
             if need_log:
                 log("爬取成功，返回内容")
@@ -92,9 +110,13 @@ def random_proxy_header_access(url: str, proxy: str = '',
 def retrieve_file(url: str, path: str, proxies: str = "",
                   require_proxy: bool = False, max_retry: int = 10,
                   sleep_time: float = 1.2, random_proxy: bool = True,
-                  need_log: bool = True) -> bool:
+                  need_log: bool = True, reporthook: Callable[[], None] = None,
+                  data: str = None) -> bool:
     """
     retrieve file from provided url and save to path
+    :param data: 使用url encode的参数
+    :param reporthook: 用来在获取url链接信息之后调用的函数,例如函数def test(a: int, b: int, c: int) -> None,
+    三个参数分别表示，当前下载第几块，每块的大小，文件的总大小
     :param need_log: 是否需要日志
     :param url: file url
     :param path: the save path
@@ -134,7 +156,7 @@ def retrieve_file(url: str, path: str, proxies: str = "",
             else:
                 opener.addheaders = [('User-Agent', ua.random)]
             urllib.request.install_opener(opener)
-            urlretrieve(url, path)
+            urlretrieve(url=url, filename=path, reporthook=reporthook, data=data)
             if need_log:
                 log("文件提取成功")
             success = True
@@ -153,7 +175,7 @@ def retrieve_file(url: str, path: str, proxies: str = "",
         return success
 
 
-def get_pdf_url_by_doi(doi: str, work_path: str, sleep_time: float=1.2, max_retry: int=10,
+def get_pdf_url_by_doi(doi: str, work_path: str, sleep_time: float = 1.2, max_retry: int = 10,
                        require_proxy: bool = False, random_proxy: bool = True,
                        proxies: bool = "", need_log: bool = True) -> None:
     """
@@ -241,7 +263,8 @@ def verify_rule(rule: dict, origin: float or str or Tag) -> bool:
             return False
         elif str(value) == NOT_EQUAL and str(key) == str(origin):
             return False
-        elif str(value) == LESS_THAN or str(value) == LESS_THAN or str(value) == LESS_THAN_AND_EQUAL or str(value) == MORE_THAN or str(value) == GREATER_AND_EQUAL:
+        elif str(value) == LESS_THAN or str(value) == LESS_THAN or str(value) == LESS_THAN_AND_EQUAL or str(
+                value) == MORE_THAN or str(value) == GREATER_AND_EQUAL:
             if type(origin) != float:
                 return False
             else:
