@@ -7,7 +7,7 @@ from loguru import logger
 import global_val
 from proxypool.schemas import Proxy
 from proxypool.storages.redis import RedisClient
-from proxypool.setting import TEST_TIMEOUT, TEST_URL, TEST_VALID_STATUS, TEST_ANONYMOUS, NEED_LOG_TESTER
+from proxypool.setting import TEST_VALID_STATUS, TEST_ANONYMOUS
 from aiohttp import ClientProxyConnectionError, ServerDisconnectedError, ClientOSError, ClientHttpProxyError
 from asyncio import TimeoutError
 from constant import *
@@ -57,15 +57,17 @@ class Tester(object):
                 # the proxy has the effect of hiding the real IP
                 if TEST_ANONYMOUS:
                     url = 'https://httpbin.org/ip'
-                    async with session.get(url, timeout=TEST_TIMEOUT) as response:
+                    async with session.get(url, timeout=global_val.get_value(TESTER_TIMEOUT)) as response:
                         resp_json = await response.json()
                         origin_ip = resp_json['origin']
-                    async with session.get(url, proxy=f'http://{proxy.string()}', timeout=TEST_TIMEOUT) as response:
+                    async with session.get(url, proxy=f'http://{proxy.string()}',
+                                           timeout=global_val.get_value(TESTER_TIMEOUT)) as response:
                         resp_json = await response.json()
                         anonymous_ip = resp_json['origin']
                     assert origin_ip != anonymous_ip
                     assert proxy.host == anonymous_ip
-                async with session.get(TEST_URL, proxy=f'http://{proxy.string()}', timeout=TEST_TIMEOUT,
+                async with session.get(global_val.get_value(TESTER_URL), proxy=f'http://{proxy.string()}',
+                                       timeout=global_val.get_value(TESTER_TIMEOUT),
                                        allow_redirects=False) as response:
                     if response.status in TEST_VALID_STATUS:
                         self.conn.max(proxy)
